luqum - A lucene query parser in Python, using PLY
#########################################################

|pypi-version| |pypi-dls| |readthedocs| |travis| |coveralls|

|logo| 

"luqum" (as in LUcene QUery Manipolator) is a tool to parse queries 
written in the `Lucene Query DSL`_ and build an abstract syntax tree 
to inspect, analyze or otherwise manipulate search queries.

Compatible with Python 3.3 & 3.4.

Installation
------------

``pip install luqum``


Dependencies
------------

PLY==3.8


Full documentation
------------------

http://luqum.readthedocs.org/en/latest/


.. _`Lucene Query DSL` : https://lucene.apache.org/core/3_6_0/queryparsersyntax.html

.. |logo| image:: https://raw.githubusercontent.com/jurismarches/luqum/master/luqum-logo.png

.. |pypi-version| image:: https://img.shields.io/pypi/v/luqum.svg
    :target: https://pypi.python.org/pypi/luqum
    :alt: Latest PyPI version
.. |pypi-dls| image:: https://img.shields.io/pypi/dm/luqum.svg
    :target: https://pypi.python.org/pypi/luqum
    :alt: Number of PyPI downloads
.. |travis| image:: http://img.shields.io/travis/jurismarches/luqum/master.svg?style=flat
    :target: https://travis-ci.org/jurismarches/luqum
.. |coveralls| image:: http://img.shields.io/coveralls/jurismarches/luqum/master.svg?style=flat
    :target: https://coveralls.io/r/jurismarches/luqum
.. |readthedocs| image:: https://readthedocs.org/projects/luqum/badge/?version=latest
    :target: http://luqum.readthedocs.org/en/latest/?badge=latest
    :alt: Documentation Status
